-- RBS ASN1 Schema Definitions
-- NetIQ Corporation 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA

-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
-- Note: Please updated the version number EVERY time this file is modified
-- VeRsIoN=NetIQ Role Based Services Schema Defintions 1.09
------------------------------------------
-- Revision History
--  1.00 - ??/1999 First revision.
--
--  1.01 - 10/2000 Schema names renamed to LDAP naming convention.
--                 Removed Tree Root containment from rbsRole object.
--                 Added domain as containment for classes.
--                 Renumbered starting with sequence number 30.
--                 Added rbsTaskTemplates, rbsTaskTemplatesURL,
--                      and rbsGALabel attributes.
--                 
--
--  1.02 - 01/2001 Added 3 new attributes:
--				rbsPageMembership
--				rbsBookMembership
--				rbsTargetObjectType
--		  Added 2 new classes:
--				rbsPage
--				rbsBook
--              Removed domain as containment for
--              rbsTask and rbsPage.
--                 
--
--  1.03 - 04/2001
--              Renamed rbsOwnedRoles to rbsOwnedCollections
--              Renamed rbsTaskParameters to rbsParameters
--              rbsParameter changed syntax from Octet String to Case
--                  Exact String
--              rbsPageMembership changed syntax from Distinguished
--                  Name to Case Exact String
--              Removed rbsBookMembership ATTRIBUTE definition
--              Add rbsContext ATTRIBUTE definition
--              rbsExternalScope changed ContainedBy from O, OU and
--                  domain to rbsCollection
--              rbsModule changed ContainedBy from O, OU and domain to
--                  rbsCollection
--              rbsRole removed Owner attribute
--              rbsRole added rbsParameters attribute
--              rbsRole changed to be a container object
--              rbsRole changed ContainedBy from C, L, O, OU and
--                  domain to rbsCollection
--              Removed rbsPage OBJECT-CLASS definition
--              Added rbsScope OBJECT-CLASS definition
--              Added rbsCollection OBJECT-CLASS definition
--              Added rbsInformation Auxiliary OBJECT-CLASS definition
--              Removed the rbsAssignedRoles and rbsOwnedRoles
--                  attributes extension to the  User, Organization,
--                  Organizational Unit and Group objects
--
--
--  1.04 - 06/2001
--              Removed the NamedBy and MustContain tags form
--                  rbsScope class object
--
--
--  1.05 - 06/2001
--              Add rbsAssignedRoles and rbsOwnedCollections attribute
--                  to Top.  This was added because of syncronization
--                  issues with NDS 7 and NDS 8 and aux classes.
--
--  1.06 - 09/2001
--              Add rbsXMLInfo attribute and assign it to rbsCollection,
--                  rbsRole, rbsTask, rbsBook, rbsScope, rbsExternalScope,
--                  rbsModule classes.
--
--  1.07 - 10/2001
--              Rev OID's for all classes that rbsXMLInfo attribute was
--                  assigned to: rbsCollection, rbsRole, rbsTask,
--                  rbsBook, rbsScope, rbsExternalScope, rbsModule.
--
--  1.08 - 11/2001
--              Remove the rbsXMLInfo attribute from the add operations
--              and use a modify operation to add the attribute
--
--  1.09 - 3/2002
--              Remove the rbsAuxInfo Auxiliary class definition.
--              This will allow us to be backwards compatible
--              with 6.x and 7.x DS versions
--
----------------------------------------------------------------------
----------------------------------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) RBS(135) NDSAttributeType(4)
--                                             NDSAttributeSyntax(5)
--                                             NDSObjectClass(6)
--              sequence number(1) revision number(1)
----------------------------------------------------------------------

RBSSchemaExtentions DEFINITIONS ::=
BEGIN

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains roles that are assigned to a particular
-- object.
--
-- Distinguished name: The name of the assigned role.
-- Interval:           The index into the rbsMember attribute of the
--                     rbsRole object for use in going back into the
--                     rbsTrusteeOf attribute of object entry to
--                     obtain the scope.
-- Level:              True  - If relation is inherited from scope
--                     down.
--                     False - If only for scope.
----------------------------------------------------------------------
"rbsAssignedRoles" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 30}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists the tasks that comprise a role.
--
-- Distinguished name: The name of the task.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsContent" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 31}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists the roles that the task is in.
--
-- Distinguished name: The name of the role.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsContentMembership" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 32}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies the necessary entry point name to invoke
-- the task.
----------------------------------------------------------------------
"rbsEntryPoint" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CE_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 33}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists objects which are associated with the role.
--
-- Distinguished name: The name of the owned role.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsMember" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 34}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains collections that a particular object owns.
--
-- Distinguished name: The name of the owned collection.
--
-- Version 1.03 Change
--      Renamed from rbsOwnedRoles
----------------------------------------------------------------------
"rbsOwnedCollections" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 35}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains a list of dependent modules.
--
-- Distinguished name: The name of the module name.
-- Interval:           The order in which the modules is placed in the
--                     path.
-- Level:              N/A
----------------------------------------------------------------------
"rbsPath" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 36}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies any necessary parameters that may be
-- needed to invoke a task and role.
--
-- Version 1.03 Change
--      Renamed from rbsTaskParameters
--      Changed syntax from Octet String to Case Exact String
----------------------------------------------------------------------
"rbsParameters" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CE_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 37}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies the rights needed to perform an individual
-- task. 
-- Note: Contains an encoded listing of all rights needed for the task
-- to be successful.
----------------------------------------------------------------------
"rbsTaskRights" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 38}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute list the objects that rights have been granted to,
-- using RBS, for a particular user, group, container or external
-- scope.
--
-- Distinguished name: The name of the user, group, container or
-- external scope
-- Interval:           Identifies a specific value in the event this
--                     attribute has multiple values.
-- Level:              True  - If relation is inherited from scope
--                     down.
--                     False - If only for scope.
----------------------------------------------------------------------
"rbsTrusteeOf" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_TYPED_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 39}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute identifies the type of module.
-- Types: Windows Exe - Windows executable
--        Windows DLL - Windows DLL
--        Java        - Java byte code
--        Jar         - Jar File
----------------------------------------------------------------------
"rbsType" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  256,
	ASN1ObjID   {2 16 840 1 113719 1 135 4 40}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains a URL. 
----------------------------------------------------------------------
"rbsURL" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_OCTET_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 41}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute stores the XML file for the task. 
----------------------------------------------------------------------
"rbsTaskTemplates" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 42}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains the base path to the URL. 
----------------------------------------------------------------------
"rbsTaskTemplatesURL" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_OCTET_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 43}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- NMAS GA Label, used to restrict access to roles based on login
-- method. 
----------------------------------------------------------------------
"rbsGALabel" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_OCTET_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 44}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
--This attribute contains pages that are assigned to a particular
-- rbsBook object.
--
-- Distinguished name: The name of an rbsPage object.
--
-- Version 1.03 Change
--      Changed syntax from Distinguished Name to Case Exact String
----------------------------------------------------------------------
"rbsPageMembership" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CE_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 45}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains the object type that the book and the page
-- administrates.
----------------------------------------------------------------------
"rbsTargetObjectType" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 46}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains the context name that the rbsScope
-- represents
--
-- Distinguished name: The context name.
--
-- Version 1.03 Change
--      Add new ATTRIBUTE definition
----------------------------------------------------------------------
"rbsContext" ATTRIBUTE ::=
{
    Operation       ADD,
    SyntaxID        SYN_DIST_NAME,
    Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
    ASN1ObjID   {2 16 840 1 113719 1 135 4 47}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains XML formatted data.
----------------------------------------------------------------------
"rbsXMLInfo" ATTRIBUTE ::=
{
	Operation       ADD,
	SyntaxID        SYN_CI_STRING,
    Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 135 4 48}
}

------------------------------------------
-- RBS Object Classes
------------------------------------------

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a rbs location.
--
-- Version 1.03 Change
--      Added OBJECT-CLASS definition
----------------------------------------------------------------------
"rbsCollection" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"Top"},
	Flags           {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"Country", "Locality",
		    "Organizational Unit", "Organization", "domain"},
 	NamedBy         {"CN"},
 	MustContain     {"CN"},
	MayContain  {
			"Owner",
			"Description"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 37 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Contains information needed to query external databases. 
--
-- Version 1.03 Change
--      Changed ContainedBy from O, OU and domain to rbsCollection
----------------------------------------------------------------------
"rbsExternalScope" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"TOP"},
	ContainedBy {"rbsCollection"},
	NamedBy         {"CN"},
	MustContain     {"CN"},
	MayContain  {
			"rbsURL",
			"Description"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 30 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This is a container that holds tasks. 
--
-- Version 1.03 Change
--      Changed ContainedBy from O, OU and domain to rbsCollection
----------------------------------------------------------------------
"rbsModule" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"TOP"},
	Flags           {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy     {"rbsCollection"},
	NamedBy         {"CN"},
	MustContain     {"CN"},
	MayContain  {
			"rbsURL",
			"rbsPath",
			"rbsType",
			"Description"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 31 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- Defines an RBS Role. 
--
-- Version 1.03 Changes
--      Added rbsParameters attribute
--      Changed to be a container object
--      Changed ContainedBy from C, L, O, OU and domain to rbsCollection
--      Removed Owner attribute
                
----------------------------------------------------------------------
"rbsRole" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"TOP"},
	Flags           {DS_EFFECTIVE_CLASS, DS_CONTAINER_CLASS},
	ContainedBy {"rbsCollection"},
	NamedBy         {"CN"},
	MustContain     {"CN"},
	MayContain  {
			"rbsContent",
			"rbsMember",
			"rbsTrusteeOf",
			"rbsGALabel",
			"rbsParameters",
			"Description"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 32 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a single task. 
----------------------------------------------------------------------
"rbsTask" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"TOP"},
	Flags           {DS_EFFECTIVE_CLASS},
	ContainedBy     {"rbsModule"},
	NamedBy         {"CN"},
	MustContain     {"CN"},
	MayContain  {
			"rbsContentMembership",
			"rbsType",
			"rbsTaskRights",
			"rbsEntryPoint",
			"rbsParameters",
			"rbsTaskTemplates",
			"rbsTaskTemplatesURL",
			"Description"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 33 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a single book. 
----------------------------------------------------------------------
"rbsBook" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"rbsTask"},
	Flags           {DS_EFFECTIVE_CLASS},
	MayContain  {
			"rbsTargetObjectType",
			"rbsPageMembership"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 34 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a scope.
--
-- Version 1.03 Change
--      Added OBJECT-CLASS definition
----------------------------------------------------------------------
"rbsScope" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"Group"},
	Flags           {DS_EFFECTIVE_CLASS},
 	ContainedBy     {"rbsRole"},
	MayContain  {"rbsContext"},
	ASN1ObjID   {2 16 840 1 113719 1 135 6 35 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- This defines an Auxiliary class.
--
-- Version 1.03 Change
--      Added OBJECT-CLASS definition
-- Version 1.09 Change
--      Removed definition for 6.x and 7.x backwards compatibility
----------------------------------------------------------------------
-- "rbsAuxInfo" OBJECT-CLASS ::=
-- {
-- 	Operation   ADD,
-- 	Flags       {DS_AUXILIARY_CLASS},
--     MayContain  {"rbsAssignedRoles", "rbsOwnedCollections"},
-- 	ASN1ObjID   {2 16 840 1 113719 1 135 6 36}
-- }


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the Top class. 
--
-- Version 1.05 Change
--      Add attributes to Top
----------------------------------------------------------------------
"Top" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsAssignedRoles", "rbsOwnedCollections"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsCollection class. 
--
-- Version 1.08 Change
--      Add attribute to rbsCollection
----------------------------------------------------------------------
"rbsCollection" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsRole class. 
--
-- Version 1.08 Change
--      Add attribute to rbsRole
----------------------------------------------------------------------
"rbsRole" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsTask class. 
--
-- Version 1.08 Change
--      Add attribute to rbsTask
----------------------------------------------------------------------
"rbsTask" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsScope class. 
--
-- Version 1.08 Change
--      Add attribute to rbsScope
----------------------------------------------------------------------
"rbsScope" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsExternalScope class. 
--
-- Version 1.08 Change
--      Add attribute to rbsExternalScope
----------------------------------------------------------------------
"rbsExternalScope" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the rbsModule class. 
--
-- Version 1.08 Change
--      Add attribute to rbsModule
----------------------------------------------------------------------
"rbsModule" OBJECT-CLASS ::=
{
   Operation            MODIFY,
   MayContain           {"rbsXMLInfo"}
}

END
