-- RBS ASN1 Schema Definitions
-- NetIQ Corporation 
-- 1233 West Loop South, Suite 810
-- Houston, TX 77027 USA

-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
-- Note: Please updated the version number EVERY time this file is modified
-- VeRsIoN=NetIQ Role Based Services Schema Defintions 1.14
------------------------------------------
-- Revision History
--  1.00 - 1.12   For past histroy see 1.12 version of file
--  1.13 - 3/2003 Start new with Version 2 definitions
--  1.14 - 9/2003 Remove NPS dependences

----------------------------------------------------------------------
----------------------------------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) RBS(135) NDSAttributeType(4)
--                                             NDSAttributeSyntax(5)
--                                             NDSObjectClass(6)
--              sequence number(1) revision number(1)
----------------------------------------------------------------------

RBSSchemaExtentions DEFINITIONS ::=
BEGIN

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains roles that are assigned to a particular
-- object.
--
-- Distinguished name: The name of the assigned role.
-- Interval:           The index into the rbsMember attribute of the
--                     rbsRole object for use in going back into the
--                     rbsTrusteeOf attribute of object entry to
--                     obtain the scope.
-- Level:              True  - If relation is inherited from scope
--                     down.
--                     False - If only for scope.
----------------------------------------------------------------------
"rbsAssignedRoles2" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 51}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists the tasks that comprise a role.
--
-- Distinguished name: The name of the task.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsContent" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 31}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists the roles that the task is in.
--
-- Distinguished name: The name of the role.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsContentMembership" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 32}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies the necessary entry point name to invoke
-- the task.
----------------------------------------------------------------------
"rbsEntryPoint" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CE_STRING,
	Flags      {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 33}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute lists objects which are associated with the role.
--
-- Distinguished name: The name of the owned role.
-- Interval:           N/A
-- Level:              N/A
----------------------------------------------------------------------
"rbsMember" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 34}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains collections that a particular object owns.
--
-- Distinguished name: The name of the owned collection.
----------------------------------------------------------------------
"rbsOwnedCollections2" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_DIST_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 52}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains a list of dependent modules.
--
-- Distinguished name: The name of the module name.
-- Interval:           The order in which the modules is placed in the
--                     path.
-- Level:              N/A
----------------------------------------------------------------------
"rbsPath" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 36}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies any necessary parameters that may be
-- needed to invoke a task and role.
----------------------------------------------------------------------
"rbsParameters" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CE_STRING,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 37}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute specifies the rights needed to perform an individual
-- task. 
-- Note: Contains an encoded listing of all rights needed for the task
-- to be successful.
----------------------------------------------------------------------
"rbsTaskRights" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_OCTET_STRING,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 38}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute list the objects that rights have been granted to,
-- using RBS, for a particular user, group, container or external
-- scope.
--
-- Distinguished name: The name of the user, group, container or
-- external scope
-- Interval:           Identifies a specific value in the event this
--                     attribute has multiple values.
-- Level:              True  - If relation is inherited from scope
--                     down.
--                     False - If only for scope.
----------------------------------------------------------------------
"rbsTrusteeOf" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_TYPED_NAME,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 39}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute identifies the type of module.
-- Types: Windows Exe - Windows executable
--        Windows DLL - Windows DLL
--        Java        - Java byte code
--        Jar         - Jar File
----------------------------------------------------------------------
"rbsType" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CI_STRING,
	Flags      {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound 1,
	UpperBound 256,
	ASN1ObjID  {2 16 840 1 113719 1 135 4 40}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
--This attribute contains pages that are assigned to a particular
-- rbsBook object.
--
-- Distinguished name: The name of an rbsPage object.
----------------------------------------------------------------------
"rbsPageMembership" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CE_STRING,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 45}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains the object type that the book and the page
-- administrates.
----------------------------------------------------------------------
"rbsTargetObjectType" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CI_STRING,
	Flags      {DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 46}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains the context name that the rbsScope
-- represents
--
-- Distinguished name: The context name.
----------------------------------------------------------------------
"rbsContext" ATTRIBUTE ::=
{
    Operation  ADD,
    SyntaxID   SYN_DIST_NAME,
    Flags      {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
    ASN1ObjID  {2 16 840 1 113719 1 135 4 47}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This attribute contains XML formatted data.
----------------------------------------------------------------------
"rbsXMLInfo" ATTRIBUTE ::=
{
	Operation  ADD,
	SyntaxID   SYN_CI_STRING,
    Flags      {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID  {2 16 840 1 113719 1 135 4 48}
}


------------------------------------------
-- RBS Object Classes
------------------------------------------

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a rbs location.
----------------------------------------------------------------------
"rbsCollection2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"Top"},
	Flags         {DS_EFFECTIVE_CLASS,
	              DS_CONTAINER_CLASS},
	ContainedBy   {"Country",
	              "Locality",
                  "Organizational Unit",
                  "Organization",
                  "domain"},
 	NamedBy       {"CN"},
 	MustContain   {"CN"},
    MayContain    {"rbsXMLInfo",
                  "rbsParameters",
			      "Owner",
			      "Description"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 45 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Contains information needed to query external databases. 
----------------------------------------------------------------------
"rbsExternalScope2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"TOP"},
	ContainedBy   {"rbsCollection2"},
	NamedBy       {"CN"},
	MustContain   {"CN"},
	MayContain    {"rbsXMLInfo",
                  "Description"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 38 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This is a container that holds tasks. 
----------------------------------------------------------------------
"rbsModule2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"TOP"},
	Flags         {DS_EFFECTIVE_CLASS,
	              DS_CONTAINER_CLASS},
	ContainedBy   {"rbsCollection2"},
	NamedBy       {"CN"},
	MustContain   {"CN"},
	MayContain    {"rbsXMLInfo",
                  "rbsPath",
                  "rbsType",
                  "Description"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 39 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- Defines an RBS Role. 
----------------------------------------------------------------------
"rbsRole2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"TOP"},
	Flags         {DS_EFFECTIVE_CLASS,
	              DS_CONTAINER_CLASS},
	ContainedBy   {"rbsCollection2"},
	NamedBy       {"CN"},
	MustContain   {"CN"},
	MayContain    {"rbsXMLInfo",
                  "rbsContent",
                  "rbsMember",
                  "rbsTrusteeOf",
                  "rbsParameters",
                  "Description"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 40 1}
}

----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a single task. 
----------------------------------------------------------------------
"rbsTask2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"TOP"},
	Flags         {DS_EFFECTIVE_CLASS},
	ContainedBy   {"rbsModule2"},
	NamedBy       {"CN"},
	MustContain   {"CN"},
	MayContain    {"rbsXMLInfo",
                  "rbsContentMembership",
                  "rbsType",
                  "rbsTaskRights",
                  "rbsEntryPoint",
                  "rbsParameters",
                  "Description"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 41 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a single book. 
----------------------------------------------------------------------
"rbsBook2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"rbsTask2"},
	Flags         {DS_EFFECTIVE_CLASS},
	MayContain    {"rbsTargetObjectType",
	               "rbsPageMembership"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 42 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- This class defines a scope.
----------------------------------------------------------------------
"rbsScope2" OBJECT-CLASS ::=
{
	Operation     ADD,
	SubClassOf    {"Group"},
	Flags         {DS_EFFECTIVE_CLASS},
 	ContainedBy   {"rbsRole2"},
	MayContain    {"rbsContext",
	              "rbsXMLInfo"},
	ASN1ObjID     {2 16 840 1 113719 1 135 6 43 1}
}


----------------------------------------------------------------------
----------------------------------------------------------------------
-- Modify the Top class.
-- We have to modify to instead of using a Aux Class
-- When an Aux Class is assigned to an object it becomes
-- unknown in ConsoleOne, NWadmin, etc.
----------------------------------------------------------------------
"Top" OBJECT-CLASS ::=
{
   Operation      MODIFY,
   MayContain     {"rbsAssignedRoles2",
                  "rbsOwnedCollections2"}
}

END
