-- Encryption Schema Definitions
--
-- VeRsIoN=1.0
-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.

-- Schema Source:           encrypt.sch
-- Description:
-- %version: 7 %
-- %date_modified:Mon Jun  4 12:30:12 2007 %

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) NDS(1) NDSAttributeType(4)
--                                            NDSAttributeSyntax(5)
--                                            NDSObjectClass(6)
--              revision number(1) sequence number(1)
------------------------------------------

EncryptionSchemaExtensions DEFINITIONS ::=
BEGIN

-- These definitions are added for Encryption feature in eDirectory 8.8. 

--
-- Attribute is used to store source replica Server DN, 
-- destination replica Server DN and encryption flag
--
--

"dsEncryptedReplicationConfig" ATTRIBUTE ::=
{
	Operation   ADD,
	Flags    {DS_SYNC_IMMEDIATE},
	SyntaxID SYN_TIMESTAMP,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 542}
}

--
--
--
"Partition" OBJECT-CLASS ::=
{
	Operation   MODIFY,
	MayContain  {"dsEncryptedReplicationConfig"}
}

------------------------------------------
-- New encryption Policy DN attribute for NCP Server Class 
------------------------------------------
"encryptionPolicyDN" ATTRIBUTE ::=
{
	SyntaxID SYN_DIST_NAME,
	Flags {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID {2 16 840 1 113719 1 1 4 1 543}
}

"NCP Server" OBJECT-CLASS ::=
{
	Operation MODIFY,
	MayContain {"encryptionPolicyDN"}
}

------------------------------------------
-- Attribute Encryption Section
-- New attribute for NCP Server Class 
-- April 28, 2004
-- attribute value 0 means does NOT require a secure channel
------------------------------------------
"attrEncryptionRequiresSecure" ATTRIBUTE ::=
{
	SyntaxID SYN_INTEGER,
	Flags {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID {2 16 840 1 113719 1 1 4 1 544}
}

------------------------------------------
-- New encryption attribute for Policy Object Class 
-- April 26, 2004
-- This definition is added for Attribute Encryption feature in eDirectory8.8
-- This definition is of type SYN_CI_LIST, each value of the attribute holds
-- the following strings:
-- o Encryption Scheme
-- o Attribute Name
--
-- Eg1: AES, HKID
-- Eg2: DES, AccountBalance
------------------------------------------
"attrEncryptionDefinition" ATTRIBUTE ::=
{
	SyntaxID SYN_CI_LIST,
	ASN1ObjID {2 16 840 1 113719 1 1 4 1 545}
}

------------------------------------------
-- encryption Policy Object Class
------------------------------------------
"encryptionPolicy" OBJECT-CLASS ::=
{
	Operation ADD,
	SubClassOf {"TOP"},
	Flags {DS_EFFECTIVE_CLASS},
	ContainedBy {"Country", "Locality", "domain",
		"Organizational Unit", "Organization"},
	NamedBy {"CN"},
	MustContain {"CN"},
	MayContain {
				"attrEncryptionDefinition",
				"attrEncryptionRequiresSecure"
		},
	ASN1ObjID   {2 16 840 1 113719 1 1 6 1 50}
}

END

