--	--------------------------------------------------------------------------
--	HTTP Server Schema Definitions
--
-- OIDs are defined as follows:
--		joint-iso-ccitt(2) country(16) us(840) organization(1) 
--						Novell(113719) 
--							applications(1) 
--								httpServer(3) 
--									httpServerAttributeType(4) 
--									httpServerAttributeSyntax(5) 
--									httpServerObjectClass(6) 
--										sequence # revision #
--
--	HTTP Server subarc: 2.16.840.1.113719.1.3
--
--	CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
--
--	Name:					httpstk.sch
--	%version:			idc_n4u#11 %
--	%date_modified:	Tue Jun  5 08:11:31 2007 %
--	--------------------------------------------------------------------------

HttpServerSchemaExtensions {2 16 840 1 113719 1 3} DEFINITIONS ::= 
BEGIN

--	--------------------------------------------------------------------------
-- New HTTP Server NCP Server Attributes
--	--------------------------------------------------------------------------

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- ncp attribute - references the associated http server

"httpServerDN" ATTRIBUTE ::=
{
	SyntaxID				SYN_DIST_NAME,
	Flags					{DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 1}
}

--	--------------------------------------------------------------------------
-- New HTTP Server Attributes
--	--------------------------------------------------------------------------

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - references the host ncp server

"httpHostServerDN" ATTRIBUTE ::=
{
	SyntaxID				SYN_DIST_NAME,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 2}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - number of threads per cpu in the IOCP thread pool

"httpThreadsPerCPU" ATTRIBUTE ::=
{
	SyntaxID    		SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 3}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - input/output network buffer size for req and rsp

"httpIOBufferSize" ATTRIBUTE ::=
{
	SyntaxID    		SYN_INTEGER,
	Flags       		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 4}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - seconds of inactivity before a persistent conn is closed

"httpRequestTimeout" ATTRIBUTE ::=
{
	SyntaxID    		SYN_INTEGER,
	Flags       		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 5}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - seconds of inactivity before a new request before closing

"httpKeepAliveRequestTimeout" ATTRIBUTE ::=
{
	SyntaxID    		SYN_INTEGER,
	Flags       		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 6}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - seconds of inactivity before a session is closed

"httpSessionTimeout" ATTRIBUTE ::=
{
	SyntaxID    		SYN_INTEGER,
	Flags       		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 7}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - references key material object to be used as server cert

"httpKeyMaterialObject" ATTRIBUTE ::=
{
	SyntaxID    		SYN_DIST_NAME,
	Flags       		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   		{2 16 840 1 113719 1 3 4 8}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - diagnostic output level - 0:none, 5:full hex TX/RX dumps

"httpTraceLevel" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 9}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - 0 means authentication does NOT require a TLS/SSL channel

"httpAuthRequiresTLS" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 10}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - default http server clear text port value

"httpDefaultClearPort" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 11}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - default http server TLS port value

"httpDefaultTLSPort" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 12}
}

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http attribute - Cipher strength restrictions

"httpBindRestrictions" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags					{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID			{2 16 840 1 113719 1 3 4 13}
}

--	--------------------------------------------------------------------------
-- The HTTP Server Object Class
--	--------------------------------------------------------------------------

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- http server class - represents an http server hosted by an ncp server

"httpServer" OBJECT-CLASS ::=
{
	Operation			ADD,
	SubClassOf			{"TOP"},
	Flags					{DS_EFFECTIVE_CLASS},
	ContainedBy
	{
		"domain",
		"Country",
		"Locality",
		"Organizational Unit",
		"Organization"
	},
	NamedBy				{"CN"},
	MustContain			{"CN"},
	MayContain
	{
		"httpHostServerDN",
		"httpThreadsPerCPU",
		"httpIOBufferSize",
		"httpRequestTimeout",
		"httpKeepAliveRequestTimeout",
		"httpSessionTimeout",
		"httpKeyMaterialObject",
		"httpTraceLevel",
		"httpAuthRequiresTLS",
		"httpDefaultClearPort",
		"httpDefaultTLSPort",
		"httpBindRestrictions"
	},
	ASN1ObjID			{2 16 840 1 113719 1 3 6 1}
}

--	--------------------------------------------------------------------------
-- Modification of Existing Classes for HTTP Server
--	--------------------------------------------------------------------------

-- ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-- required so the http server can find itself via the ncp server object

"NCP Server" OBJECT-CLASS ::=
{
	Operation			MODIFY,
	MayContain			{"httpServerDN"}
}

--	--------------------------------------------------------------------------

END

