-- NDS Base Schema Definitions
-- NetIQ Corporation 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA

-- %version:		idc_n4u#64 %
-- %date_modified:	Mon Jul 23 05:54:13 2007 %
--
-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--  joint-iso-ccitt(2) country(16) us(840) organization(1)
--  Novell(113719) applications(1) NDS(1)  NDSAttributeType(4)
--                                         NDSAttributeSyntax(5)
--                                         NDSObjectClass(6)
--          revision number(1) sequence number(1)
------------------------------------------
-- One Additional value was added before the attribute or object
-- identifier (shown as sequence number above) to identify the version
-- number.  This number reflects the version number in which the object 
-- or attribute was added to the definition.  The first version would 
-- have the ID 1 and count up from there.
-- An example of the attribute of the first revision with sequence 1 would be:
-- 2 16 840 1 113719 1 1 4 1 1.
-- The attribute of the third revision with sequence 4 would be:
-- 2 16 840 1 113719 1 1 4 3 4.
--
-- In fall of 1999, format was change to reverse the version and sequence
-- numbers, and suppress the first version (which would default to 0).
-- Thus the first number above would now be 2 16 840 1 113719 1 1 4 1
-- and the second would be 2 16 840 1 113719 1 1 4 4 3
------------------------------------------

NDSSchemaExtensions {2 16 840 1 113719 1 1} DEFINITIONS ::=
BEGIN

--
-- This definition was added for NDS 8 in 12/98.  It is a special definition
-- intended to cause a schema extension "failure" if the appropriate version
-- of DSRepair (? what option) has not already been run.  This "gate" 
-- definition causes the file to abort if the schema in the tree is not already
-- up to a minimum version.  By itself, it does nothing, because the DSI tool
-- can not add a new naming attribute to an existing definition, which 
-- "Organizational Person" is.  If DSRepair has been run already, then the 
-- definition is already set to this value, so it matches, and is ignored
-- and the file will continue to be processed.
--
"Organizational Person"	OBJECT-CLASS ::=
{
   Operation	ADD,
   SubClassOf	{"Person"},
   NamedBy	{"uniqueID"},
   MayContain	{"uniqueID"}
}

--
-- Original NetWare 5 extension.  Currently stores permanent state of IPX 
-- Checksum flag, CRC32 flag, and Ensure All Servers Up flag.  
-- Currently only stored on special internal only object.  
--
"Permanent Config Parms" ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 177}
}

--
-- Original NetWare 5 extension.  Add the Permanent Config Parms attribute.
-- Intention is to eventually store this information on NCP Server object,
-- and have the local object be a static cache of the "real" information
-- which would be managable from any management utility.
--
"NCP Server"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Permanent Config Parms"}
}

--
-- Original NetWare 5 extension.  Defines the timezone attribute for both
-- Servers and "loginable objects".  The Timezone attribute contains a 
-- TIMEZONE_INFO structure.
--
-- The following time stuctures were adapted from Windows 95 and Windows NT 
-- system time information
--
--   typedef struct TIME
--	{
--	  uint16 year;		/* current year */
--	  uint16 month;		/* January is 1 */
--	  uint16 dayOfWeek;	/* Sunday is 0, ... Saturday is 6 */
--	  uint16 dayOfMonth;	/* 1-28, 29, 30, 31               */
--	  uint16 hour;		/* 0 (midnight) to 23 (11:00pm)   */
--	  uint16 minute;	/* 0 to 59 */
--	  uint16 second;	/* 0 to 59 */
--	  uint16 milliSecond;	/* 0       */
--	} TIME;
--
--   typedef struct TIMEZONE_INFO
--	{
--	  int32   utcBias;  	/* Offset from UTC time in minutes, UTC = localTime + bias */
--	  unicode stdName[32];	/* Name of the standard time zone, EST, MST */
--	  int32   stdBias;	/* offset to add to utcBias during standard time, 0 in most cases */
--	  TIME    stdStart;	/* Transition date and UTC time from Daylight to standard. all zeroes if not specified */
--	  unicode dstName[32];	/* Name of daylight savings time, EDT, MDT etc */
--	  int32   dstBias;	/* offset to add to utcBias during daylight savings time. -60 in most cases */
--	  TIME    dstStart;	/* Transition date and time in UTC from standard to daylight time */
--	} TIMEZONE_INFO;
--
--
"Timezone"		ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 178}
}

--
-- Original NetWare 5 extension.  Add timezone attribute to servers.
-- Users get timezone from ndsLoginProperties.
--
"Server"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Timezone"}
}

--
-- Original NetWare 5 extension.  This attribute can optionally be added
-- to O or OU class objects.  If present and non-zero on a container that
-- is in the bindery context, it limits the rights of objects that are
-- equivalent to the server object.
--
"Bindery Restriction Level"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_INTEGER,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 179}
}

--
-- Original NetWare 5 extension.  Contains information about the current 
-- synchronization status of the partition (from this server's perspective)
-- it is attached to.
--
"Partition Status"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 176}
}

--
-- Original NetWare 5 extension.  Contains information about the 
-- synchronization status of the partition it is attached to.
--
"Transitive Vector"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_PUBLIC_READ},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 180}
}

--
-- Original NetWare 5 extension.
--
"Partition"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Partition Status", "Transitive Vector"}
}

--
-- Added for NDS 8.  This attribute helps control sending incremental 
-- changes during synchronization.
--
"Local Received Up To"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PER_REPLICA, DS_READ_ONLY_ATTR, DS_PUBLIC_READ},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 508}
}

"Partition"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Local Received Up To"}
}

--
-- Original NetWare 5 extension.  This is the naming attribute for 
-- Tree Root class.
--
"T"			ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SIZED_ATTR},
   SyntaxID	SYN_CI_STRING,
   LowerBound	1,
   UpperBound	32,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 181}
}

--
-- Original NetWare 5 extension.  Defines the Tree Root class.
--
"Tree Root"		OBJECT-CLASS ::=
{
   Operation	ADD,
   Flags	{DS_CONTAINER_CLASS},
   SubClassOf	{"Top"},
   NamedBy	{"T"},
   MustContain	{"T"}
}

--
-- Original NetWare 5 extension.  This attribute controls when a deleted
-- value may be purged on the local server.
--
"Purge Vector"		ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
   SyntaxID	SYN_TIMESTAMP,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 183}
}

--
-- Original NetWare 5 extension.  This attribute is to be used by management
-- software to determine if the synchronization status is within the desired
-- tolerance level for purposes of being "in sync".
--
"Synchronization Tolerance"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
   SyntaxID	SYN_TIMESTAMP,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 184}
}

--
-- Original NetWare 5 extension.  This attribute is added to a partition root
-- when an object that is referenced (but not present) within the partition
-- is modified, renamed, deleted, etc.  This is used to cleanup the local
-- reference to the object.
--
"Obituary Notify"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 500}
}

--
-- Original NetWare 5 extension.
--
"Partition"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Purge Vector", "Synchronization Tolerance", 
		 "Obituary Notify"}
}

--
-- Original NetWare 5 extension.  This is a special attribute definition, and
-- is not intended to ever be added to any class definition, or ever actually
-- instantiated.  Its purpose is to be referenced in ACLs to grant management
-- rights for "passwords", which are held in other attributes, not in a 
-- "password" attribute.
--
"Password Management"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_UNKNOWN,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 185}
}

--
-- Original NetWare 5 extension.  This attribute holds the DRL, a reference 
-- to a partition root object of the partition where this object is 
-- referenced by some other object in that partition.
--
"Used By"		ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_SERVER_READ},
   SyntaxID	SYN_PATH,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 186}
}

--
-- Original NetWare 5 extension.  Holds a Globally Unique Identifer.
--
"GUID"			ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PUBLIC_READ, DS_SYNC_IMMEDIATE, DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   LowerBound	16,
   UpperBound	16,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 501}
}

--
-- Original NetWare 5 extension.  Holds old GUIDs that have been previously
-- assigned to this object.
--
"Other GUID"		ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PUBLIC_READ, DS_SYNC_IMMEDIATE, DS_SIZED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   LowerBound	16,
   UpperBound	16,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 502}
}

--
-- Original NetWare 5 extension.  Extend Top to have common attributes.
--
"Top"			OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Used By", "GUID", "Other GUID"}
}

--
-- Original NetWare 5 extension.  Last part of the DRL attribute set.  Similar 
-- to the "Used by" attribute, but maintained by external service agents, where
-- NDS maintains the "Used by" itself.
--
"Uses"			ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_SERVER_READ},
   SyntaxID	SYN_PATH,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 187}
}

--
-- Original NetWare 5 extension.  Add the Uses attribute to all resources.
--
"Resource"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Uses"}
}

--
-- Added for NDS 8 for LDAP compatibility.  Holds aux class information to 
-- be synchronized to older non-aux class aware servers.
--
"Auxiliary Class Flag"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_READ_ONLY_ATTR, DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_UNKNOWN,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 503}
}

--
-- Added for NDS 8 for LDAP compatibility.  Holds aux class information to 
-- be synchronized to older non-aux class aware servers.
--
"Unknown Auxiliary Class"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SIZED_ATTR},
   SyntaxID	SYN_CI_STRING,
   LowerBound	1,
   UpperBound	32,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 504}
}

--
-- Added for NDS 8 for LDAP compatibility.  Holds aux class information to 
-- be synchronized to older non-aux class aware servers.
--
"AuxClass Object Class Backup"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR},
   SyntaxID	SYN_CLASS_NAME,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 507}
}

--
-- Added for NDS 8 for LDAP compatibility
-- It is defined by the X.500 Directory Pilot definition which assigned 
-- the OID.  This oid is actually assigned to "userID".  NetIQ's LDAP 
-- implementation maps this attribute to "uid", which we thought was supposed
-- to be "unique" rather than "user".
--
"uniqueID"		ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_PUBLIC_READ, DS_SIZED_ATTR},
   SyntaxID	SYN_CI_STRING,
   LowerBound	1,
   UpperBound	64,
   ASN1ObjID	{0 9 2342 19200300 100 1 1}
}

--
-- Added for NDS 8 for LDAP compatibility
-- dc is the naming attribute for domain, and also used for the dcObject
-- auxiliary class naming attribute.  
-- It is defined by the X.500 Directory Pilot definition which assigned 
-- the OID.  The attribute name in the Directory pilot definition is
-- "domainComponent".
--
"dc"			ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SIZED_ATTR},
   SyntaxID	SYN_CI_STRING,
   LowerBound	1,
   UpperBound	64,
   ASN1ObjID	{0 9 2342 19200300 100 1 25}
}

--
-- Added for NDS 8 for LDAP compatibility.  Generic LDAP container class.
--
"domain"		OBJECT-CLASS ::=
{
   Operation	ADD,
   Flags	{DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
   SubClassOf	{"Top"},
   ContainedBy	{"domain", "Top", "Tree Root", "Country", 
		 "Locality", "Organization", "Organizational Unit"},
   NamedBy	{"dc"},
   MustContain	{"dc"},
   ASN1ObjID	{0 9 2342 19200300 100 4 13}
}

--
-- Added for NDS 8 for LDAP compatibility.  Generic LDAP aux class to allow
-- use of "dc=" naming for any object.
--
"dcObject"		OBJECT-CLASS ::=
{
   Operation	ADD,
   Flags	{DS_AUXILIARY_CLASS},
   NamedBy	{"dc"},
   MustContain	{"dc"},
   ASN1ObjID	{1 3 6 1 4 1 1466 344}
}

--
-- Added Jan 2000 for DNS support.  This defines the type of federation being
-- made.  Options are FEDERATION_NORMAL (0): Accepts schema extensions, and
-- Subordinate partitions can be split off. FEDERATION_FIXED_SCHEMA (3): 
-- Schema cannot be extended. Subordinate partitions cannot be split off.
--
"federationBoundaryType" ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_INTEGER,
   ASN1ObjID	{2 16 840 1 113719 1 141 4 1}
}

--
-- Added Jan 2000 for DNS support.  This attribute contains a list of 
-- strings that indicate how name resolution should find names that cross 
-- federation boundaries (names from other management trees). Federation 
-- information is retrieved and used in the order that it occurs in the
-- list. Each list element is of the form "tag:data". Currently there are 
-- two possible values for "tag:" - "dns:" and "slp:". Strings that do 
-- not contain a tag followed by the ':' character are assumed to be DNS 
-- names or dotted decimal IP addresses. 
--
-- DNS strings indicate addresses of servers that may be able to resolve 
-- a DNS name. In this list DNS names are useful only if a server that 
-- holds a replica of this partition has enough other DNS configuration
-- information to resolve the DNS name to an address. An empty DNS string 
-- indicates that the resolver code should use the server-specific DNS 
-- configuration information, e.g. DNS server addresses from a local 
-- registry or file. 
--
-- The data portion of an "slp:" string indicates the SLP scope to be 
-- searched for addresses of NDS partitions that can resolve the name.
--
"federationSearchPath"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_CI_LIST,
   ASN1ObjID	{2 16 840 1 113719 1 141 4 2}
}

--
-- Added Jan 2000 for DNS support.  Before federation can occur, independent 
-- trees must have an object in the DNS naming tree (the dnsTreeProxy) 
-- from which addresses of servers within the independent tree may be 
-- obtained. This attribute attaches the dnsTreeProxy name to the root 
-- object of independent trees.
--
"federationDNSName"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_DIST_NAME,
   ASN1ObjID	{2 16 840 1 113719 1 141 4 3}
}

--
-- Added Jan 2000 for DNS support.  The integer portion of the values of 
-- this attribute is not used and should be zero. The distinguished named
-- field must contain a name of either a root of a management trees 
-- (partition roots with the federationBoundary auxiliary class) or a 
-- dnsFederationList object.  Furthermore, all names must be names in the
-- DNS naming tree. The string field of values of this attribute are for 
-- use by the server and should be set to empty by the client.
--
"federationControl"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE},
   SyntaxID	SYN_PATH,
   ASN1ObjID	{2 16 840 1 113719 1 141 4 4}
   
}

"Partition"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"federationControl"}
}

--
-- Added Jan 2000 for DNS support. This is a new auxiliary class that 
-- contains a mandatory, read-only attribute. Therefore this class can only
-- be added to objects by the server.  It is only meaningful on partition 
-- roots, i.e. objects which also have the 'partition' auxiliary class.  
-- The presence of this auxiliary class indicates that the partition is the 
-- root of a management tree. 
--
"federationBoundary"	OBJECT-CLASS ::=
{
   Operation	ADD,
   Flags	{DS_AUXILIARY_CLASS},
   MustContain	{"federationBoundaryType"},
   MayContain	{"federationControl", "federationDNSName", 
		 "federationSearchPath"},
   ASN1ObjID	{2 16 840 1 113719 1 141 6 1}

}

--
-- Added Jan 2000 for DirXML driver support.  Associates a DirXML driver with
-- an object.
--
"DirXML-Associations"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE},
   SyntaxID	SYN_PATH,
   ASN1ObjID	{2 16 840 1 113719 1 14 4 1 4}
}

--
-- Added post NDS 8 for DirXML support.
--
"Top"			OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"DirXML-Associations"}
}

--
-- Add in NDS 8 to make all login related attributes be grouped for easy 
-- inheritance to any class of object needing to log in.  This was not added
-- to the schema file earlier because it was determined that it must be added
-- via DSRepair in order to be inserted into superclass list for person, etc.
--
"ndsLoginProperties"	OBJECT-CLASS ::=
{
   Operation	ADD,
   SubClassOf	{"Top"},
   MayContain	{"Group Membership", "Login Allowed Time Map",
		 "Login Disabled", "Login Expiration Time",
		 "Login Grace Limit", "Login Grace Remaining",
		 "Login Intruder Address", "Login Intruder Attempts",
		 "Login Intruder Reset Time", "Login Maximum Simultaneous",
		 "Login Script", "Login Time", "Network Address Restriction",		
		 "Network Address", "Passwords Used", "Password Allow Change",
		 "Password Expiration Interval", "Password Expiration Time",
		 "Password Minimum Length", "Password Required",
		 "Password Unique Required", "Private key", "Profile",
		 "Public Key", "Security Equals", "Account Balance",
		 "Allow Unlimited Credit", "Minimum Account Balance",
		 "Language", "Locked By Intruder", "Server Holds",
		 "Last Login Time", "Higher Privileges", "Security Flags", 
		 "Profile Membership", "Timezone"},
   ASN1ObjID	{2 16 840 1 113719 1 1 6 1 33}
}

--
-- Add ndsLoginProperties as superclass for Person, O, OU, and domain
--
"Person"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsLoginProperties"}
}

"Organization"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsLoginProperties"}
}

"Organizational Unit"	OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsLoginProperties"}
}

"domain"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsLoginProperties"}
}

--
-- Define the set of login related attributes that must be held and managed
-- at the parent container level, rather than the object level
--
"ndsContainerLoginProperties"	OBJECT-CLASS ::=
{
   Operation	ADD,
   SubClassOf	{"Top"},
   MayContain	{"Login Intruder Limit", "Intruder Attempt Reset Interval",
		 "Detect Intruder", "Lockout After Detection",
		 "Intruder Lockout Reset Interval"},
   ASN1ObjID	{2 16 840 1 113719 1 1 6 1 34}
}

--
-- Add ndsContainerLoginProperties as superclass for O, OU, and domain
--
"Organization"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsContainerLoginProperties"}
}

"Organizational Unit"	OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsContainerLoginProperties"}
}

"domain"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   SubClassOf	{"ndsContainerLoginProperties"}
}

--
-- Added Jan 2000 for LDAP operational attribute support.  
--
-- creatorsName stores the DN of the user that created the entry
--

"creatorsName"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR},
   SyntaxID	SYN_CI_STRING,
   ASN1ObjID	{2 5 18 3}
}

--
-- modifiersName stores the DN of the user that last modified the entry
--

"modifiersName"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR},
   SyntaxID	SYN_CI_STRING,
   ASN1ObjID	{2 5 18 4}
}

--
-- Added post NDS 8 for LDAP operational attribute support.
--

"Top"			OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"creatorsName", "modifiersName"}
}

-- 
-- ndsPredicateStatsExtentions DEFINITIONS
--

---------------------------------------------------------
-- Specific new attributes for ndsPredicateStats class
---------------------------------------------------------

"ndsPredicate" ATTRIBUTE ::=
{
	SyntaxID    SYN_NET_ADDRESS,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 35}
}

"ndsPredicateState" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 36}
}

"ndsPredicateFlush" ATTRIBUTE ::=
{
	SyntaxID    SYN_BOOLEAN,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 37}
}

"ndsPredicateTimeout" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE, DS_SIZED_ATTR},
	LowerBound  0,
	UpperBound  2147483647,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 38}
}

"ndsPredicateUseValues" ATTRIBUTE ::=
{
 SyntaxID    SYN_BOOLEAN,
 Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
 ASN1ObjID   {2 16 840 1 113719 1 27 4 39}
}

---------------------------------------------
-- Specific Attributes for NCP Server class
---------------------------------------------

"ndsPredicateStatsDN" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 40}
}

---------------------------------------------------------
-- New object class: ndsPredicateStats
---------------------------------------------------------

"ndsPredicateStats" OBJECT-CLASS ::=
{
	Operation   ADD,
	SubClassOf  {"Top"},
	Flags       {DS_EFFECTIVE_CLASS},
	ContainedBy {"Country", "Locality", "Organizational Unit", "Organization", "domain"},
	NamedBy	    {"CN"},
	MustContain {"CN", "ndsPredicateState", "ndsPredicateFlush"},
	MayContain  {"ndsPredicate", "ndsPredicateTimeout"},
	ASN1ObjID   {2 16 840 1 113719 1 27 6 3}
}

---------------------------------------------------------
-- Modify ndsPredicateStats 
---------------------------------------------------------

"ndsPredicateStats" OBJECT-CLASS ::=
{
   Operation      MODIFY,
   MayContain     {"ndsPredicateUseValues"}
}

---------------------------------------------------------
-- Modify NCP Server 
---------------------------------------------------------

"NCP Server" OBJECT-CLASS ::=
{
   Operation      MODIFY,
   MayContain     {"ndsPredicateStatsDN"}
}

--
-- Added Feb 2000, extensions to "Top" so mutate information can be kept if mutate fails
--

--
--  "Unknown Base Class" existed previously, but was not included in nds500.sch
--

"Unknown Base Class"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_CI_STRING,
   LowerBound	1,
   UpperBound	32,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 110}
}

"Top"			OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"Unknown Base Class", "Unknown Auxiliary Class"}
}

---------------------------------------------------------
-- Specific new attribute for index definitions 
-- added Feb 2001
---------------------------------------------------------

"indexDefinition"  ATTRIBUTE ::=
{
	SyntaxID  SYN_CI_LIST,
	ASN1ObjID {2 16 840 1 113719 1 1 4 1 512}
}

"languageId"  ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE},
	SyntaxID  SYN_CI_STRING,
	ASN1ObjID {2 16 840 1 113719 1 1 4 1 300}
}

"NCP Server" OBJECT-CLASS ::=
{
   Operation      MODIFY,
   MayContain     {"indexDefinition", "languageId"}
}

---------------------------------------------------------
-- Specific new attribute for synchronization of NDS
-- added Feb 2001
---------------------------------------------------------
"syncWindowVector"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PER_REPLICA, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 600}
}

"syncPanePoint"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PER_REPLICA, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 601}
}

"Partition"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"syncWindowVector", "syncPanePoint"}
}

"objectVersion"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_TIMESTAMP,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 602}
}


"auxClassCompatibility"	ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_SYNC_IMMEDIATE, DS_READ_ONLY_ATTR, DS_PUBLIC_READ},
   SyntaxID	SYN_CLASS_NAME,
   ASN1ObjID	{2 16 840 1 113719 1 1 4 1 525}
}


"Top"			OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"objectVersion", "auxClassCompatibility"}
}

---------------------------------------------------------
-- New attribute and class for DynamicGroup Feature 
-- added May 2001
---------------------------------------------------------

"memberQuery" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 301}
}

"excludedMember" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 302}
}

---------------------------------------------------------
-- added Dec 2001
---------------------------------------------------------
"ndsStatusRepair" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 513}
}

"ndsStatusExternalReference" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 514}
}

"ndsStatusObituary" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 515}
}

"ndsStatusSchema" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 516}
}

"ndsStatusLimber" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 517}
}

"ndsAgentPassword" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_HIDDEN_ATTR, DS_READ_ONLY_ATTR, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 518}
}

"ndsOperationCheckpoint" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 519}
}

"localReferral" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 520}
}

"treeReferral" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 521}
}


"schemaResetLock" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 522}
}


"modifiedACLEntry" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 523}
}


"monitoredConnection" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 524}
}

"localFederationBoundary" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 526}
}

"replicationFilter" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 527}
}

---------------------------------------------------------
-- added Jan 2002
---------------------------------------------------------
--
-- Added to disable account login until after activation time.
--
"loginActivationTime" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_TIME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE, DS_OPERATIONAL},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 296}
}

--
-- Added Login Activation Time as optional
--
"ndsLoginProperties"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"loginActivationTime"}
}

---------------------------------------------------------
-- added Jun 2002
---------------------------------------------------------
--
-- Used to mark a partition root as non-authoritative.
--
"authoritative"					ATTRIBUTE ::=
{
	Operation	ADD,
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 511}
}

"Partition"						OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"authoritative"}
}

--
-- Specifies a reference in URI form (RFC 2079)
--
"ref"							ATTRIBUTE ::=
{
	Operation	ADD,
	SyntaxID	SYN_CE_STRING,
	ASN1ObjID	{2 16 840 1 113730 3 1 34}
}

--
-- Used to hold an immediate superior reference (analogous to immsupr DSE type in X.501)
--
"immediateSuperiorReference"	OBJECT-CLASS ::=
{
	Operation	ADD,
	Flags		{DS_AUXILIARY_CLASS},
	MayContain	{"ref"},
	ASN1ObjID	{2 16 840 1 113719 1 1 6 1 47}	
}

---------------------------------------------------------
-- added July 2004
---------------------------------------------------------
--
-- Used to cache additional attributes on external references
--
"CachedAttrsOnExtRefs" ATTRIBUTE ::=
{
	Operation	ADD,
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SYNC_IMMEDIATE, DS_SERVER_READ},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 546}
}

--
-- Used to store the last sync time of external references
--
"ExtRefLastUpdatedTime" ATTRIBUTE ::=
{
	Operation	ADD,
	SyntaxID			SYN_TIMESTAMP,
	Flags				{DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_OPERATIONAL, DS_PUBLIC_READ, DS_PER_REPLICA},
	ASN1ObjID			{2 16 840 1 113719 1 1 4 1 547}
}

"NCP Server"	OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"CachedAttrsOnExtRefs"}
}

--
-- Used for Secure NCP
--

"NCPKeyMaterialName" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID		SYN_CI_STRING,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_PUBLIC_READ},
	ASN1ObjID		{2 16 840 1 113719 1 1 4 688}
}

"NCP Server"	OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"NCPKeyMaterialName"}
}

---------------------------------------------------------
-- added June 2005
---------------------------------------------------------
--
-- Used to store the entryIDs of the partition roots whose partitions are 
-- being updated with AncestorIDs after move partition.
--
"UpdateInProgress" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_OPERATIONAL},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 1 4 687}
}

---------------------------------------------------------
-- added Mar 2007
---------------------------------------------------------
--
-- Extensions to support login scripts with UTF-8 characters.
--
"UTF8LoginScript" ATTRIBUTE ::=
{
   Operation		ADD,
   Flags			{DS_SYNC_IMMEDIATE},
   SyntaxID		SYN_STREAM,
   ASN1ObjID		{2 16 840 1 113719 1 1 4 713}
}

--
-- Indicates the character set in which the "Login Script" attribute is encoded.
--
"loginScriptCharset"	ATTRIBUTE ::=
{
	Operation	ADD,
	SyntaxID		SYN_CI_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 1 4 714}
}

--
-- Add "UTF8LoginScript" and "loginScriptCharset" as optional
--
"ndsLoginProperties"		OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"UTF8LoginScript", "loginScriptCharset"}
}

"dsContainerReadyAttrs" ATTRIBUTE ::=
{
        Operation               ADD,
        Flags                   {DS_OPERATIONAL},
        SyntaxID                SYN_CI_STRING,
        ASN1ObjID               {2 16 840 1 113719 1 1 4 720}
}

"NDSRightsToMonitor" ATTRIBUTE ::=
{
	Operation		ADD,
	SyntaxID		SYN_CI_STRING,
	Flags			{DS_PER_REPLICA},
	ASN1ObjID		{2 16 840 1 113719 1 1 4 721}
}

"NCP Server"	OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"NDSRightsToMonitor"}
}

"HVAConfig" ATTRIBUTE ::=
{
        Operation               ADD,
        SyntaxID                SYN_STREAM,
        Flags                   {DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
        ASN1ObjID               {2 16 840 1 113719 1 1 4 722}
}

"NCP Server"    OBJECT-CLASS ::=
{
        Operation       MODIFY,
        MayContain      {"HVAConfig"}
}

END

