-- NetIQ Common Application ASN1 Schema Definitions
-- NetIQ Corporation 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA

-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
-- Note: Please updated the version number EVERY time this file is modified
-- VeRsIoN=NetIQ Common Schema Defintions 1.02
------------------------------------------
-- Revision History
--  1.00 - 10/99 Original file creation.  Contains digitalMeID
--  1.01 - 03/00 Added homePhone, mobile, and pager definitions, 
--         added all 3 to Person and Template
--  1.02 - 04/00 Added "Zero Day Start" defines, "contingentWorker" 
--         and "homeInfo" Auxiliary Classes.  All new attributes defined
--         that were not in an auxiliary class were added to the Person
--         class definition, and many were also added to Template class def.

------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) Novell Common (8)
------------------------------------------

NovellCommonSchemaExtentions {2 16 840 1 113719 1 8} DEFINITIONS ::=
BEGIN

------------------------------------------
--  Added for InstantMe project, 10/99
------------------------------------------
"digitalMeID"    ATTRIBUTE ::=
{
  SyntaxID    SYN_PATH,
  Flags          {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
  ASN1ObjID   {2 16 840 1 113719 1 8 4 1}
}


"assistant" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_DIST_NAME,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 2}
}

"assistantPhone" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 3}
}

"city" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 4}
}


"company" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 5}
}

-- specifies name of countries in human readable from
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"co" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {0 9 2342 19200300 100 1 43}
}

"directReports" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_DIST_NAME,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 6}
}

-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"manager" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_DIST_NAME,
  ASN1ObjID   {0 9 2342 19200300 100 1 10}
}

"mailstop" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 7}
}

-- "Work Cell Phone" in PeopleSoft
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"mobile" ATTRIBUTE ::=
{
  SyntaxID    SYN_TEL_NUMBER,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {0 9 2342 19200300 100 1 41}
}

-- "Business Title" in PeopleSoft
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"personalTitle" ATTRIBUTE ::=
{
  SyntaxID    SYN_CI_STRING,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {0 9 2342 19200300 100 1 40}
}

-- "Pager" in PeopleSoft
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"pager" ATTRIBUTE ::=
{
  SyntaxID    SYN_TEL_NUMBER,
  Flags       {DS_SYNC_IMMEDIATE},
  ASN1ObjID   {0 9 2342 19200300 100 1 42}
}

-- workforceID  - used by PeopleSoft
"workforceID" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 8}
}

"instantMessagingID" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 9}
}

-- preferredName - "Preferred Name" in PeopleSoft
"preferredName" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 10}
}

-- photo - "Picture" in EPI or Westinghouse
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"photo" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_OCTET_STRING,
  ASN1ObjID   {0 9 2342 19200300 100 1 7}
}

-- jobCode - "Job Code" in PeopleSoft
"jobCode" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 11}
}

-- siteLocation - "Location Code" in PeopleSoft
"siteLocation" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 12}
}

-- employeeStatus - "Employee Status" in PeopleSoft
--    Active, Leave, Paid leave, Suspended, Deceased, Terminated, Retired, ...
"employeeStatus" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 13}
}

-- employeeType - "Employee Class" in PeopleSoft
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"employeeType" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113730 3 1 4}
}

-- costCenter - "Account Code" in PeopleSoft
"costCenter" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 14}
}

-- costCenterDescription - "Account Code Description" in PeopleSoft
"costCenterDescription" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 15}
}

-- tollFreePhoneNumber - "800 Phone" in PeopleSoft
"tollFreePhoneNumber" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 16}
}

-- otherPhoneNumber - "Optional Phone" in PeopleSoft
"otherPhoneNumber" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 17}
}

-- managerWorkforceID  - "Manager WorkforceID" in PeopleSoft
"managerWorkforceID" ATTRIBUTE ::=
{
  Flags        {DS_SYNC_IMMEDIATE},
  SyntaxID     SYN_CI_STRING,
  ASN1ObjID    {2 16 840 1 113719 1 8 4 18}
}

-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"roomNumber" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {0 9 2342 19200300 100 1 6}
}

"jackNumber" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 19}
}

-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"departmentNumber" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113730 3 1 2}
}

"vehicleInformation" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 20}
}

"accessCardNumber" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 21}
}

"isManager" ATTRIBUTE ::=
{
  Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_BOOLEAN,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 32}
}

-- attributes for homeInfo auxClass

"homeCity" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 22}
}

"homeEmailAddress" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 23}
}

-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"homeFax" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {1 3 6 1 4 1 1466 101 120 31}
}

-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"homePhone" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {0 9 2342 19200300 100 1 20}
}

"homeState" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 24}
}
								  
-- definition from RFC 2798 - Definition of the inetOrgPerson LDAP Object Class
"homePostalAddress" ATTRIBUTE ::=
{
  Flags          {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_PO_ADDRESS,
  ASN1ObjID   {0 9 2342 19200300 100 1 39}
}

"homeZipCode" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 25}
}

-- personalMobile - "Personal Cell Phone" in PeopleSoft
"personalMobile" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 26}
}


"children" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 27}
}

"spouse" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 28}
}

"homeInfo" OBJECT-CLASS ::=
{
  Operation   ADD,
  Flags       {DS_AUXILIARY_CLASS},
  MayContain  {"homeCity", "homeEmailAddress", "homeFax", "homePhone", 
           "homeState", "homePostalAddress", "homeZipCode", 
               "personalMobile", "spouse", "children"},
  ASN1ObjID   {2 16 840 1 113719 1 8 6 1}
}

-- attributes for contingentWorker auxClass
"vendorName" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 29}
}

"vendorAddress" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_CI_STRING,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 30}
}

"vendorPhoneNumber" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE},
  SyntaxID    SYN_TEL_NUMBER,
  ASN1ObjID   {2 16 840 1 113719 1 8 4 31}
}

"dgIdentity" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_WRITE_MANAGED},
  SyntaxID    SYN_DIST_NAME,
  ASN1ObjID   {2 16 840 1 113719 1 1 4 1 303}
}

"dgTimeOut" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
  SyntaxID    SYN_INTEGER,
  ASN1ObjID   {2 16 840 1 113719 1 1 4 1 304}
}

"dgAllowUnknown" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
  SyntaxID    SYN_BOOLEAN,
  ASN1ObjID   {2 16 840 1 113719 1 1 4 1 305}
}

"dgAllowDuplicates" ATTRIBUTE ::=
{
  Flags       {DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
  SyntaxID    SYN_BOOLEAN,
  ASN1ObjID   {2 16 840 1 113719 1 1 4 1 306}
}

"contingentWorker" OBJECT-CLASS ::=
{
  Operation   ADD,
  Flags       {DS_AUXILIARY_CLASS},
  MayContain  {"vendorName", "vendorAddress", "vendorPhoneNumber"},
  ASN1ObjID   {2 16 840 1 113719 1 8 6 2}
}


"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"assistant"}
}



"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  { "assistantPhone"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"city"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"S"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"company"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"co"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"directReports"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"manager"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"mailstop"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"mobile"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"personalTitle"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"pager"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"workforceID"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"instantMessagingID"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"preferredName"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"photo"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"jobCode"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"siteLocation"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"employeeStatus"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"employeeType"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"costCenter"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"costCenterDescription"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"tollFreePhoneNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"otherPhoneNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"managerWorkforceID"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"roomNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"jackNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"departmentNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"vehicleInformation"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"accessCardNumber"}
}

"Person" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"isManager"}
}

"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"assistant"}
}



"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"assistantPhone"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"city"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"S"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"company"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"co"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"manager"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"managerWorkforceID"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"mailstop"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"siteLocation"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"employeeType"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"costCenter"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"costCenterDescription"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"tollFreePhoneNumber"}
}


"Template" OBJECT-CLASS ::=
{
  Operation   MODIFY,
  MayContain  {"departmentNumber"}
}

"dynamicGroup" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"Group", "ndsLoginProperties"},
	Flags           {DS_EFFECTIVE_CLASS},
	MayContain  {
			"memberQuery", "excludedMember",
			"dgIdentity", "dgAllowUnknown",
			"dgTimeout", "dgAllowDuplicates"
	},
	ASN1ObjID   {2 16 840 1 113719 1 1 6 1 45}
}

"dynamicGroupAux" OBJECT-CLASS ::=
{
	Operation       ADD,
	SubClassOf      {"Group", "ndsLoginProperties"},
	Flags           {DS_AUXILIARY_CLASS},
	MayContain  {
			"memberQuery", "excludedMember",
			"dgIdentity", "dgAllowUnknown",
			"dgTimeout", "dgAllowDuplicates"
	},
	ASN1ObjID   {2 16 840 1 113719 1 1 6 1 46}
}

---------------------------------------------------------
-- added Dec 2001
---------------------------------------------------------
"ndsStatusRepair" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 513}
}

"ndsStatusExternalReference" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 514}
}

"ndsStatusObituary" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 515}
}

"ndsStatusSchema" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 516}
}

"ndsStatusLimber" ATTRIBUTE ::=
{
   Operation	ADD,
	SyntaxID	SYN_OCTET_STRING,
	ASN1ObjID	{2 16 840 1 113719 1 1 4 1 517}
}

-- This attribute is added for VSLDAP in eDirectory 8.7.3 IR4.
--
-- Allow or disallow creation of an alias pointing to its ancestor
-- default - Not allowed
--
"allowAliasToAncestor"			ATTRIBUTE ::=
{
	Operation   ADD,
	Flags    {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	SyntaxID SYN_BOOLEAN,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 546}
}

-- 
-- 
-- 
"Partition"				OBJECT-CLASS ::=
{
   Operation	MODIFY,
   MayContain	{"allowAliasToAncestor"}
}

END
