-- Secure Authentication Services Schema Definitions
-- NetIQ Corporation 
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA

-- VeRsIoN=SAS 1.0
-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- Object ID's Defined as Follows:
--   joint-iso-ccitt(2) country(16) us(840) organization(1)
--   Novell(113719) applications(1) SAS(39) 
--						          	SASAttributeType(4)
--                           		SASAttributeSyntax(5)
--                         			SASObjectClass(6)
------------------------------------------


SASSchemaExtentions {0 0 0 0 0 0 0 0 0 0} DEFINITIONS ::=
BEGIN
-- 
-- New Attributes
--

"SAS:Security DN" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_DIST_NAME,	
	Flags        	{DS_SINGLE_VALUED_ATTR,
		 			DS_SYNC_IMMEDIATE,
		 			DS_SERVER_READ},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 1}
}

"SAS:Service DN" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_DIST_NAME,	
	Flags        	{DS_SINGLE_VALUED_ATTR,
		 			DS_SYNC_IMMEDIATE,
		 			DS_SERVER_READ},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 2}
}

-- New Attribute for Secret Store added 10 Dec 1998
"SAS:SecretStore" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_BOOLEAN,	
	Flags        	{DS_SINGLE_VALUED_ATTR,
		 			DS_SYNC_IMMEDIATE},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 3}
}

"SAS:SecretStore:Key" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_OCTET_STRING,	
	Flags        	{DS_SINGLE_VALUED_ATTR,
		 			DS_SYNC_IMMEDIATE,
		 			DS_HIDDEN_ATTR},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 4}
}

"SAS:SecretStore:Data" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_OCTET_STRING,	
	Flags        	{DS_SYNC_IMMEDIATE,
		 			DS_HIDDEN_ATTR},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 5}
}

"SAS:PKIStore:Keys" ATTRIBUTE ::=
{
	Operation    	ADD,
	SyntaxID     	SYN_OCTET_STRING,	
	Flags        	{DS_SYNC_IMMEDIATE,
		 			DS_HIDDEN_ATTR},
 	ASN1ObjID    	{2 16 840 1 113719 1 39 4 1 6}
}


--
-- New Classes
--
"SAS:Security" OBJECT-CLASS ::=
{
  Operation     ADD,
  Flags         {DS_CONTAINER_CLASS, DS_EFFECTIVE_CLASS},
  SubClassOf    {"Top"},
  ContainedBy   {"Top"},
  NamedBy       {"CN"},
  MustContain   {"CN"},
  ASN1ObjID     {2 16 840 1 113719 1 39 6 1 1}
}


"SAS:Service" OBJECT-CLASS ::=
{
	Operation    ADD,
	Flags		{DS_EFFECTIVE_CLASS},
	SubClassOf	{"Resource"},
	NamedBy		{"CN"},
	MayContain	{"Host Server",
			 	"Private Key",
			 	"Public Key"},
 	ASN1ObjID  	{2 16 840 1 113719 1 39 6 1 2}
}

-- 
-- Modify exsiting classes
--
"NCP Server" OBJECT-CLASS ::=
{
 	Operation    MODIFY,
	MayContain 	{"SAS:Service DN"}
}

-- Modify for Secret Store added 10 Dec 1998
"User" OBJECT-CLASS ::=
{
 	Operation   MODIFY,
	MayContain 	{"SAS:Service DN",
               "SAS:SecretStore",
               "SAS:SecretStore:Key",
			   "SAS:SecretStore:Data",
			   "SAS:PKIStore:Keys"
              	}
}

-- Modify SAS:Service to allow Service Authentication added 9 Feb 1999
"SAS:Service" OBJECT-CLASS ::=
{
 	Operation   MODIFY,
	MayContain 	{
					"Allow Unlimited Credit",
					"Full Name",
					"Last Login Time",
					"Locked By Intruder",
					"Login Allowed Time Map",
					"Login Disabled",
					"Login Expiration Time",
					"Login Intruder Address",
					"Login Intruder Attempts",
					"Login Intruder Reset Time",
					"Login Maximum Simultaneous",
					"Login Time",
					"Network Address",
					"Network Address Restriction",
					"Notify",
					"Operator",
					"Owner",
					"Path",
					"Security Equals",
					"Security Flags",
					"Status",
					"Version"
              	}
}
END

